# -*- coding: utf-8 -*-

from .base import BaseRESTAPI
from .group_open_http_svc import GroupOpenHttpSVC  # 群组管理
from .im_open_login_svc import IMOpenLoginSVC  # 帐号管理
from .open_im import OpenIM  # 单聊消息
from .profile import Profile  # 资料管理
from .sns import SNS  # 关系链管理
from .open_config_svr import OpenConfigSVR  # 运营管理
from .open_msg_svc import OpenMSGSVC  # 消息记录
